<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="85"/>
        <source>Enter the number to configure: </source>
        <translation>설정할 번호를 입력하세요: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="90"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="18"/>
        <source>Loading packages...</source>
        <translation>패키지 로드 중...</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="19"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 로드됨</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="22"/>
        <source>Initializing...</source>
        <translation>초기화 중...</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="18"/>
        <source>OK</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="118"/>
        <source>Package Installer</source>
        <translation>패키지 관리자</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="128"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="695"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="819"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>기타 패키지 설치 중... 나중에 열어주세요.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="700"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>파싱 실패: 메타데이터 파일에서 잘못된 파일 구조가 발견되었습니다!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="702"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>파싱 실패: 메타데이터 파일에서 잘못된 버전 번호가 발견되었습니다!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="704"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>deb 패키지가 없습니다. 폴더를 확인해주세요.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="842"/>
        <source>The %1 package may be broken</source>
        <translation>%1 패키지가 손상되었을 수 있습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="851"/>
        <source>You can only install local %1 packages</source>
        <translation>로컬 %1 패키지만 설치할 수 있습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="860"/>
        <source>No permission to access this folder</source>
        <translation>이 폴더에 접근할 권한이 없습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="877"/>
        <source>Already Added</source>
        <translation>이미 추가됨</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="886"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1이 존재하지 않습니다. 다시 선택해주세요</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="445"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="894"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="1047"/>
        <source>Bulk Install</source>
        <translation>일괄 설치</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
        <source>Installation failed, please check your network connection</source>
        <translation>설치 실패. 네트워크 연결을 확인하십시오</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>설치 실패. 제어 센터에서 업데이트를 확인하십시오</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="133"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>설치 실패, 디스크 공간 부족</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="139"/>
        <source>No digital signature</source>
        <translation>디지털 서명이 없습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="144"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="895"/>
        <source>Invalid digital signature</source>
        <translation>잘못된 디지털 서명</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="152"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="880"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1981"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>관리자가 이 패키지 설치를 방지하는 정책을 설정했습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="159"/>
        <source>Installation Failed</source>
        <translation>설치 실패</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="863"/>
        <source>current system</source>
        <translation>현재 시스템</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="866"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation>%2가 %1에 설치되어 있습니다. 설치하기 전에 이 패키지를 제거해주세요</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="873"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation>파손된 종속성입니다. 호환 모드로 앱을 설치해보세요</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="876"/>
        <source>Compatibility mode installation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="898"/>
        <source>Failed to install %1</source>
        <translation>%1 설치 실패</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1328"/>
        <source>Unable to install - no digital signature</source>
        <translation>설치할 수 없습니다 - 디지털 서명이 없음</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1329"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>개발자 모드를 활성화하려면 제어 센터로 이동하여 다시 시도해주세요. 계속할까요?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1332"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1333"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>계속</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1280"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1394"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1983"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1284"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>%1 설치 실패: 유효한 디지털 서명이 없습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1435"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>이 패키지에는 유효한 디지털 서명이 없습니다. 설치를 계속할까요?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1437"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1438"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>계속</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1278"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1391"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1980"/>
        <source>Unable to install</source>
        <translation>설치할 수 없음</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1392"/>
        <source>This package does not have a valid digital signature</source>
        <translation>이 패키지에는 유효한 디지털 서명이 없습니다.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="902"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="908"/>
        <source>Broken dependencies: %1</source>
        <translation>깨진 종속성: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="149"/>
        <source>Authentication failed</source>
        <translation>인증 실패</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="834"/>
        <source>Unmatched package architecture</source>
        <translation>최고의 패키지 아키텍처</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="51"/>
        <source>Drag deb packages here</source>
        <translation>deb 패키지를 여기로 끌어다 놓으십시오</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="93"/>
        <source>Select File</source>
        <translation>파일 선택</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Show details</source>
        <translation>상세 정보 표시</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="179"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>설치</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="180"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>완료</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="182"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>뒤로</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="545"/>
        <source>Install %1 will remove: </source>
        <translation>%1 설치는 다음을 제거할 것입니다: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="563"/>
        <source>Dependencies in the repository</source>
        <translation>저장소의 종속성</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="570"/>
        <source>Missing dependencies</source>
        <translation>결여된 종속성</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="629"/>
        <source>Installing dependencies: %1</source>
        <translation>종속성 설치 중: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="87"/>
        <source>Same version installed</source>
        <translation>동일한 버전 설치됨</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="91"/>
        <source>Earlier version installed: %1</source>
        <translation>이전 버전 설치: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="96"/>
        <source>Later version installed: %1</source>
        <translation>이후 버전 설치: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="102"/>
        <source>Unmatched package architecture</source>
        <translation>최고의 패키지 아키텍처</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Select all</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="24"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>설치</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="62"/>
        <source>Installing</source>
        <translation>설치중</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="66"/>
        <source>Installed</source>
        <translation>설치됨</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="74"/>
        <source>Failed</source>
        <translation>실패함</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="70"/>
        <source>Waiting</source>
        <translation>기다리는 중</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="246"/>
        <source>Same version installed</source>
        <translation>동일한 버전 설치됨</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="248"/>
        <source>Later version installed: %1</source>
        <translation>이후 버전 설치: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="250"/>
        <source>Earlier version installed: %1</source>
        <translation>이전 버전 설치: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="189"/>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="52"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>축소</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>기본</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>개발자 모드가 활성화된 경우 디지털 서명을 확인합니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="88"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation>서명이 없는 앱을 설치하려면 보안 센터 &gt; 도구 &gt; 앱 보안으로 이동하고 설치할 수 있는 앱 유형을 선택하세요.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="90"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation>보안 센터 &gt; 도구 &gt; 앱 보안</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="54"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation>시스템에 Linglong 환경이 설치되지 않았습니다. 먼저 설치해 주세요.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Unable to install</source>
        <translation>설치할 수 없음</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="49"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation>이 패키지에는 유효한 디지털 서명이 없어 설치/실행이 차단되었습니다. 설정을 변경하려면 보안 센터 &gt; 도구 &gt; 앱 보안으로 이동하세요.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="52"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">취소</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="53"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>계속</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="282"/>
        <source>Will remove: </source>
        <translation>제거할 항목: </translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1035"/>
        <source>Collapse</source>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="519"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1233"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1438"/>
        <source>Reinstall</source>
        <translation>재설치</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1238"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1443"/>
        <source>Later version installed: %1</source>
        <translation>이후 버전 설치: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1239"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1444"/>
        <source>Downgrade</source>
        <translation>다운그레이드</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1244"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1449"/>
        <source>Earlier version installed: %1</source>
        <translation>이전 버전 설치: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1336"/>
        <source>Installing dependencies: %1</source>
        <translation>종속성 설치 중: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1499"/>
        <source>Failed to install %1</source>
        <translation>%1 설치 실패</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="244"/>
        <source>Version: </source>
        <translation>버전:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="190"/>
        <source>Select a compatibility mode:</source>
        <translation>호환성 모드를 선택하세요:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="511"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>설치</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="515"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>제거</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="523"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="527"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>뒤로</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="531"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>완료</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="777"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="818"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation>%1 호환성 모드에서 %2을 설치 중입니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="858"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation>%1 호환성 모드에서 %2을 제거 중입니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="987"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation>%2이 %1 호환성 모드로 성공적으로 설치되었습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="991"/>
        <source>Installed successfully</source>
        <translation>설치 성공</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1000"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation>%2이 %1 호환성 모드에서 성공적으로 제거되었습니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Uninstalled successfully</source>
        <translation>제거 성공</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Uninstall Failed</source>
        <translation>제거 실패</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1070"/>
        <source>Install %1 will remove: </source>
        <translation>%1 설치 시 제거할 항목: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1091"/>
        <source>Dependencies in the repository</source>
        <translation>저장소에 있는 종속성</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1098"/>
        <source>Missing dependencies</source>
        <translation>결여된 종속성</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1245"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1450"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>업데이트</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1505"/>
        <source>Invalid digital signature</source>
        <translation>유효하지 않은 디지털 서명</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="232"/>
        <source>Name: </source>
        <translation>이름:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1232"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1437"/>
        <source>Same version installed</source>
        <translation>동일한 버전 설치됨</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="762"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="984"/>
        <source>Show details</source>
        <translation>상세 정보 표시</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="51"/>
        <source>Show dependencies</source>
        <translation>종속성 표시</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="843"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="997"/>
        <source>Show details</source>
        <translation>상세 정보 표시</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="557"/>
        <source>Installation Failed</source>
        <translation>설치 실패</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Show related packages</source>
        <translation>관련 패키지 표시</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="41"/>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>%1을(를) 제거하시겠습니까?
모든 종속성도 제거됩니다</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="133"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>%1을(를) 제거하시겠습니까?
시스템 또는 다른 응용 프로그램이 제대로 작동하지 않을 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="177"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation>%1 호환성 모드에서 %2을 정말로 제거하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>패키지 관리자</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>패키지 설치 관리자는 사용자가 로컬 패키지를 설치하고, 제거할 수 있도록 지원하고 일괄 설치를 지원합니다.</translation>
    </message>
</context>
</TS>
